==> lhcsmapi-1.1.185.tar.gz: lhcsmapi-1.1.185/lhcsmapi/analysis/nqps/NqpsPlot.py <==
import matplotlib.pyplot as plt

from ...Time import Time


class NqpsPlot(object):

    @staticmethod
    def plot_i_meas_nqps_voltage(i_meas_df, nqps_signal_dfs, timestamp_fgc_act, circuit_name, *, signal):
        title = '{} {} I_MEAS(t) and {}(t)'.format(Time.convertToString(timestamp_fgc_act)[:23], circuit_name,
                                                         signal)
        ax1 = i_meas_df["I_MEAS"].plot(title=title, color='C0', figsize=(15, 7.5), grid=True)
        ax1.title.set_size(20)
        ax1.legend(['I_MEAS'], loc='lower left')
        ax1.set_xlabel("time, [s]", fontsize=15)
        ax1.set_ylabel("I_MEAS, [A]", fontsize=15, color='C0')
        ax1.tick_params(labelsize=15)

        ax2 = ax1.twinx()
        ax2.set_ylabel("{}, [V]".format(signal), fontsize=15)
        ax2.tick_params(labelsize=15)
        for nqps_signal_df in nqps_signal_dfs:
            nqps_signal_df.plot(ax=ax2, legend=False)
        plt.show()

        ax1 = i_meas_df["I_MEAS"].plot(title=title, color='C0', figsize=(15, 7.5), xlim=(-10, +10), grid=True)
        ax1.title.set_size(20)
        ax1.legend(['I_MEAS'], loc='lower left')
        ax1.set_xlabel("time, [s]", fontsize=15)
        ax1.set_ylabel("I_MEAS, [A]", fontsize=15, color='C0')
        ax1.tick_params(labelsize=15)

        ax2 = ax1.twinx()
        ax2.set_ylabel("{}, [V]".format(signal), fontsize=15)
        ax2.tick_params(labelsize=15)
        for nqps_signal_df in nqps_signal_dfs:
            nqps_signal_df.plot(ax=ax2, legend=False, xlim=(-2, +3))
        plt.show()

==> lhcsmapi-1.2.19.tar.gz: lhcsmapi-1.2.19/lhcsmapi/analysis/nqps/NqpsPlot.py <==
import matplotlib.pyplot as plt

from ...Time import Time


class NqpsPlot(object):

    @staticmethod
    def plot_i_meas_nqps_voltage(i_meas_df, nqps_signal_dfs, timestamp_fgc_act, circuit_name, *, signal):
        title = '{} {} I_MEAS(t) and {}(t)'.format(Time.to_string_short(timestamp_fgc_act), circuit_name,
                                                   signal)
        ax1 = i_meas_df["I_MEAS"].plot(title=title, color='C0', figsize=(15, 7.5), grid=True)
        ax1.title.set_size(20)
        ax1.legend(['I_MEAS'], loc='lower left')
        ax1.set_xlabel("time, [s]", fontsize=15)
        ax1.set_ylabel("I_MEAS, [A]", fontsize=15, color='C0')
        ax1.tick_params(labelsize=15)

        ax2 = ax1.twinx()
        ax2.set_ylabel("{}, [V]".format(signal), fontsize=15)
        ax2.tick_params(labelsize=15)
        for nqps_signal_df in nqps_signal_dfs:
            if not nqps_signal_df.empty:
                nqps_signal_df.plot(ax=ax2, legend=False)
        plt.show()

        ax1 = i_meas_df["I_MEAS"].plot(title=title, color='C0', figsize=(15, 7.5), xlim=(-10, +10), grid=True)
        ax1.title.set_size(20)
        ax1.legend(['I_MEAS'], loc='lower left')
        ax1.set_xlabel("time, [s]", fontsize=15)
        ax1.set_ylabel("I_MEAS, [A]", fontsize=15, color='C0')
        ax1.tick_params(labelsize=15)

        ax2 = ax1.twinx()
        ax2.set_ylabel("{}, [V]".format(signal), fontsize=15)
        ax2.tick_params(labelsize=15)
        for nqps_signal_df in nqps_signal_dfs:
            if not nqps_signal_df.empty:
                nqps_signal_df.plot(ax=ax2, legend=False, xlim=(-2, +3))
        plt.show()
